# remirepo spec file for php-pecl-parallel
#
# SPDX-FileCopyrightText:  Copyright 2019-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%{?scl:          %scl_package        php-pecl-parallel}

%bcond_without  tests

%global pie_vend  pecl
%global pie_proj  parallel
%global pecl_name parallel
%global ini_name  40-%{pecl_name}.ini
%global sources   %{pecl_name}-%{version}

Summary:        Parallel concurrency API
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        1.2.7
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  %{?scl_prefix}php-zts-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  autoconf

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}                    = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}            = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})              = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}         = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj})    = %{version}


%description
A succinct parallel concurrency API for PHP.

This extension is only available for PHP in ZTS mode.

Documentation: http://php.net/parallel

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}

# Sanity check, really often broken
extver=$(sed -n '/define PHP_PARALLEL_VERSION/{s/.* "//;s/".*$//;p}' php_parallel.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable "%{summary}" extension module
extension=%{pecl_name}
EOF


%build
cd %{sources}

%{__ztsphpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

%configure \
    --enable-parallel \
    --with-php-config=%{__ztsphpconfig}

%make_build


%install
cd %{sources}

: Install the extension
%make_install

: Install config file
install -D -m 644 ../%{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}

: Install XML package description
install -D -m 644 ../package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

: INstall Documentation
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do sed -e 's/\r//' -i $i
   install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for the extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with tests}
: Upstream test suite  for the extension
TEST_PHP_ARGS="-n -d extension=$PWD/modules/%{pecl_name}.so" \
SKIP_ONLINE_TESTS=1 \
%{__ztsphp} -n -q run-tests.php --show-diff %{?_smp_mflags}
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so


%changelog
* Wed Jun 18 2025 Remi Collet <remi@remirepo.net> - 1.2.7-1
- update to 1.2.7

* Wed Jan 29 2025 Remi Collet <remi@remirepo.net> - 1.2.6-1
- update to 1.2.6
- re-license spec file to CECILL-2.1

* Mon Nov  4 2024 Remi Collet <remi@remirepo.net> - 1.2.5-1
- update to 1.2.5

* Mon Aug 26 2024 Remi Collet <remi@remirepo.net> - 1.2.4-1
- update to 1.2.4

* Mon Jul 22 2024 Remi Collet <remi@remirepo.net> - 1.2.3-1
- update to 1.2.3

* Mon Jul  1 2024 Remi Collet <remi@remirepo.net> - 1.2.2-1
- update to 1.2.2

* Sat Oct 29 2022 Remi Collet <remi@remirepo.net> - 1.2.1-1
- update to 1.2.1

* Mon Oct 24 2022 Remi Collet <remi@remirepo.net> - 1.2.0-1
- update to 1.2.0
- raise dependency on PHP 8.0

* Thu Sep 17 2020 Remi Collet <remi@remirepo.net> - 1.1.4-1
- update to 1.1.4

* Wed Aug 14 2019 Remi Collet <remi@remirepo.net> - 1.1.3-1
- update to 1.1.3

* Thu Jun 13 2019 Remi Collet <remi@remirepo.net> - 1.1.2-1
- update to 1.1.2

* Wed Jun  5 2019 Remi Collet <remi@remirepo.net> - 1.1.1-1
- update to 1.1.1

* Mon Jun  3 2019 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0

* Mon May 27 2019 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3

* Thu May 23 2019 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Tue May 21 2019 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Mon May 20 2019 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0 (stable)

* Wed May  8 2019 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0
- raise dependency on PHP 7.2

* Mon Mar 25 2019 Remi Collet <remi@remirepo.net> - 0.8.3-1
- update to 0.8.3 (beta)

* Thu Feb 28 2019 Remi Collet <remi@remirepo.net> - 0.8.2-1
- update to 0.8.2 (beta)

* Mon Feb 25 2019 Remi Collet <remi@remirepo.net> - 0.8.1-1
- update to 0.8.1 (beta)

* Mon Feb 18 2019 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0 (beta)

* Tue Feb 12 2019 Remi Collet <remi@remirepo.net> - 0.0.1-0
- initial package
- test build for upcoming version 0.0.1 (beta)
